@@ -11,16 +11,18 @@ class ProgressLogMetric:
         self.name: str = name
         self.start_time: datetime = datetime.now()
 
-    def __enter__(self) -> 'ProgressLogMetric':
+    def __enter__(self) -> "ProgressLogMetric":
         return self.start()
 
     def __exit__(
-        self, exc_type: Optional[BaseException],
-        exc_value: Optional[BaseException], traceback: Optional[TracebackType]
+        self,
+        exc_type: Optional[BaseException],
+        exc_value: Optional[BaseException],
+        traceback: Optional[TracebackType],
     ) -> None:
         self.stop()
 
-    def start(self) -> 'ProgressLogMetric':
+    def start(self) -> "ProgressLogMetric":
         """
         start
         :return:
@@ -34,9 +36,8 @@ class ProgressLogMetric:
         """
         if self.name and self.progress_logger:
             end_time: datetime = datetime.now()
-            time_diff_in_minutes: float = (end_time - self.start_time
-                                           ).total_seconds() // 60
+            time_diff_in_minutes: float = (
+                end_time - self.start_time
+            ).total_seconds() // 60
             if self.progress_logger:
-                self.progress_logger.log_metric(
-                    self.name, time_diff_in_minutes
-                )
+                self.progress_logger.log_metric(self.name, time_diff_in_minutes)
